@@ -1,13 +1,13 @@
 """Html Highlight extension for Markdown.
 
-Adds the possibility to use "??? something ???" to create a span that looks like <mark>something</mark>
+Adds the possibility to use "??? something ???" or ___ something ___ to create a span that looks like <mark>something</mark>
 """
 
 from markdown.inlinepatterns import SimpleTagPattern
 from markdown.extensions import Extension
 
 # Global Vars
-MARK_RE =r'(\?{3}|_{3})([^\?]+?)(\?{3}|_{3})'  
+MARK_RE =r'(\?{3}|_{3})(.*?)(\?{3}|_{3})'  
 
 class HighlightExtension(Extension):
     """Adds MARK_RE extension to Markdown class."""
